'use strict';

var extend = require('safe-extend');
require('face-icon/lib/index.css');
require('./index.css');
function setProps() {
    message.el.wrapNode.setAttribute('class', message._config.prefixClassName + '-wrap');
}
var message = {
    el: {},
    _config: {
        duration: 3,
        prefixClassName: 'face-message',
        iconMap: {
            'info': 'info-of',
            'success': 'check-of',
            'error': 'close-of',
            'warn': 'warning-of',
            'loading': 'loading'
        }
    },
    init: function init() {
        var message = this;
        message.el.wrapNode = document.createElement('div');
        setProps();
        document.body.appendChild(message.el.wrapNode);
    },
    config: function config(settings) {
        this._config = extend(true, this._config, settings);
        setProps();
    },
    show: function show(type, content, duration) {
        var message = this;
        duration = typeof duration === 'undefined' ? message._config.duration : duration;
        if (duration === false) {
            // 60*24*30
            duration = 43200;
        }
        if (typeof message.el.wrapNode === 'undefined') {
            message.init();
        }
        var itemNode = document.createElement('div');
        var prefixClassName = message._config.prefixClassName;
        itemNode.setAttribute('class', prefixClassName + '-item');
        itemNode.innerHTML = '\n        <div class="' + prefixClassName + ' ' + prefixClassName + '--themes-' + type + '">\n            <span class="' + prefixClassName + '-icon">\n                <div class="fi fi-' + (message._config.iconMap[type] || type) + '"></div>\n            </span>\n            <div class="' + prefixClassName + '-content">\n            </div>\n        </div>\n        ';
        var messageNode = itemNode.getElementsByClassName(prefixClassName)[0];
        var contentNode = itemNode.getElementsByClassName(prefixClassName + '-content')[0];
        if (typeof content === 'string') {
            contentNode.innerHTML = content;
        } else {
            contentNode.appendChild(content);
        }
        message.el.wrapNode.appendChild(itemNode);
        setTimeout(function () {
            messageNode.setAttribute('class', messageNode.getAttribute('class') + (' ' + prefixClassName + '--fadein'));
        }, 10);
        var command = {
            el: {
                root: itemNode,
                message: messageNode,
                content: contentNode
            }
        };
        command.hide = function () {
            messageNode.setAttribute('class', messageNode.getAttribute('class') + (' ' + prefixClassName + '--fadeout'));
            setTimeout(function () {
                message.el.wrapNode.removeChild(itemNode);
            }, 500);
            command.hide = function () {};
        };
        setTimeout(function () {
            command.hide();
        }, duration * 1000);
        return command;
    },
    info: function info(content, duration) {
        return this.show('info', content, duration);
    },
    success: function success(content, duration) {
        return this.show('success', content, duration);
    },
    error: function error(content, duration) {
        return this.show('error', content, duration);
    },
    warn: function warn(content, duration) {
        return this.show('warn', content, duration);
    },
    loading: function loading(content, duration) {
        return this.show('loading', content, duration);
    }
};
message.loadingBar = require('./bar');
module.exports = message;